@@ -13,3 +13,7 @@ print "bool feature is off:", $gb->is_off('bool-feature'), "\n";
 print "string feature:", $gb->get_feature_value('string-feature'),"\n";
 print "number feature:", $gb->get_feature_value('number-feature'),"\n";
 print "json feature:", Dumper($gb->get_feature_value('json-feature')),"\n";
+$gb->set_attributes({ id => 1});
+print "bool attribute: ", ($gb->is_on('bool-attribute')),"\n";
+$gb->set_attributes({ id => 123});
+print "bool attribute: ", ($gb->is_on('bool-attribute')),"\n";
